.. -*- mode: ReST -*-

.. _files:

=====
Files
=====

.. contents:: Contents


:ref:`jgdv.files` provides some readers and writers for file formats.
Currently that is a simple `Bookmarks` format with tags,
and a `Tags` file format for storing, merging and substituting tags.
